@@ -1,20 +1,20 @@
-from peerplays.instance import shared_peerplays_instance
+from peerplays.instance import BlockchainInstance
 from .exceptions import EventGroupDoesNotExistException
-from .blockchainobject import BlockchainObject
+from .blockchainobject import BlockchainObject, ObjectCache
 
 
 class EventGroup(BlockchainObject):
     """ Read data about an event group on the chain
 
         :param str identifier: Identifier
-        :param peerplays peerplays_instance: PeerPlays() instance to use when
+        :param peerplays blockchain_instance: PeerPlays() instance to use when
             accesing a RPC
 
     """
     type_id = 17
 
     def refresh(self):
-        data = self.peerplays.rpc.get_object(self.identifier)
+        data = self.blockchain.rpc.get_object(self.identifier)
         if not data:
             raise EventGroupDoesNotExistException(self.identifier)
         super(EventGroup, self).__init__(data)
@@ -36,11 +36,17 @@ class EventGroups(list):
 
         :param str sport_id: Sport ID (``1.16.xxx``)
     """
-    def __init__(self, sport_id, peerplays_instance=None):
-        self.peerplays = peerplays_instance or shared_peerplays_instance()
-        self.eventgroups = self.peerplays.rpc.list_event_groups(sport_id)
+    cache = ObjectCache()
+
+    def __init__(self, sport_id, *args, **kwargs):
+        BlockchainInstance.__init__(self, *args, **kwargs)
+        if sport_id in EventGroups.cache:
+            self.eventgroups = EventGroups.cache[sport_id]
+        else:
+            self.eventgroups = self.blockchain.rpc.list_event_groups(sport_id)
+            EventGroups.cache[sport_id] = self.eventgroups
 
         super(EventGroups, self).__init__([
-            EventGroup(x, lazy=True, peerplays_instance=peerplays_instance)
+            EventGroup(x, lazy=False, blockchain_instance=self.blockchain)
             for x in self.eventgroups
         ])
