@@ -131,7 +131,7 @@ class PeerPlays(object):
         self.unsigned = bool(kwargs.get("unsigned", False))
         self.expiration = int(kwargs.get("expiration", 30))
         self.bundle = bool(kwargs.get("bundle", False))
-        self.blocking = kwargs.get("blocking", False)
+        self.blocking = bool(kwargs.get("blocking", False))
 
         # Legacy Proposal attributes
         self.proposer = kwargs.get("proposer", None)
@@ -151,7 +151,7 @@ class PeerPlays(object):
         # txbuffers/propbuffer are initialized and cleared
         self.clear()
 
-        self.wallet = Wallet(peerplays_instance=self, **kwargs)
+        self.wallet = Wallet(blockchain_instance=self, **kwargs)
 
     # -------------------------------------------------------------------------
     # Basic Calls
@@ -200,6 +200,12 @@ class PeerPlays(object):
         Account(account)
         config["default_account"] = account
 
+    def set_blocking(self, block=True):
+        """ This sets a flag that forces the broadcast to block until the
+            transactions made it into a block
+        """
+        self.blocking = block
+
     def finalizeOp(self, ops, account, permission, **kwargs):
         """ This method obtains the required private keys if present in
             the wallet, finalizes the transaction, signs it and
@@ -286,7 +292,7 @@ class PeerPlays(object):
                 of the transactions.
         """
         if tx:
-            txbuffer = TransactionBuilder(tx, peerplays_instance=self)
+            txbuffer = TransactionBuilder(tx, blockchain_instance=self)
         else:
             txbuffer = self.txbuffer
         txbuffer.appendWif(wifs)
@@ -301,7 +307,8 @@ class PeerPlays(object):
         """
         if tx:
             # If tx is provided, we broadcast the tx
-            return TransactionBuilder(tx).broadcast()
+            return TransactionBuilder(
+                tx, blockchain_instance=self).broadcast()
         else:
             return self.txbuffer.broadcast()
 
@@ -310,6 +317,24 @@ class PeerPlays(object):
         """
         return self.rpc.get_dynamic_global_properties()
 
+    # -------------------------------------------------------------------------
+    # Wallet stuff
+    # -------------------------------------------------------------------------
+    def newWallet(self, pwd):
+        """ Create a new wallet. This method is basically only calls
+            :func:`peerplays.wallet.create`.
+
+            :param str pwd: Password to use for the new wallet
+            :raises peerplays.exceptions.WalletExists: if there is already a
+                wallet created
+        """
+        return self.wallet.create(pwd)
+
+    def unlock(self, *args, **kwargs):
+        """ Unlock the internal wallet
+        """
+        return self.wallet.unlock(*args, **kwargs)
+
     # -------------------------------------------------------------------------
     # Transaction Buffers
     # -------------------------------------------------------------------------
@@ -361,7 +386,8 @@ class PeerPlays(object):
         parent=None,
         proposer=None,
         proposal_expiration=None,
-        proposal_review=None
+        proposal_review=None,
+        **kwargs
     ):
         if not parent:
             parent = self.tx()
@@ -380,8 +406,9 @@ class PeerPlays(object):
             proposer,
             proposal_expiration,
             proposal_review,
-            peerplays_instance=self,
-            parent=parent
+            blockchain_instance=self,
+            parent=parent,
+            **kwargs,
         )
         if parent:
             parent.appendOps(proposal)
@@ -395,7 +422,7 @@ class PeerPlays(object):
         """
         builder = TransactionBuilder(
             *args,
-            peerplays_instance=self,
+            blockchain_instance=self,
             **kwargs
         )
         self._txbuffers.append(builder)
@@ -429,14 +456,14 @@ class PeerPlays(object):
         if not account:
             raise ValueError("You need to provide an account")
 
-        account = Account(account, peerplays_instance=self)
-        amount = Amount(amount, asset, peerplays_instance=self)
-        to = Account(to, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
+        amount = Amount(amount, asset, blockchain_instance=self)
+        to = Account(to, blockchain_instance=self)
 
         memoObj = Memo(
             from_account=account,
             to_account=to,
-            peerplays_instance=self
+            blockchain_instance=self
         )
 
         op = operations.Transfer(**{
@@ -529,13 +556,13 @@ class PeerPlays(object):
             )
 
         try:
-            Account(account_name, peerplays_instance=self)
+            Account(account_name, blockchain_instance=self)
             raise AccountExistsException
         except:
             pass
 
-        referrer = Account(referrer, peerplays_instance=self)
-        registrar = Account(registrar, peerplays_instance=self)
+        referrer = Account(referrer, blockchain_instance=self)
+        registrar = Account(registrar, blockchain_instance=self)
 
         " Generate new keys from password"
         from peerplaysbase.account import PasswordKey, PublicKey
@@ -581,15 +608,15 @@ class PeerPlays(object):
             active_key_authority.append([k, 1])
 
         for k in additional_owner_accounts:
-            addaccount = Account(k, peerplays_instance=self)
+            addaccount = Account(k, blockchain_instance=self)
             owner_accounts_authority.append([addaccount["id"], 1])
         for k in additional_active_accounts:
-            addaccount = Account(k, peerplays_instance=self)
+            addaccount = Account(k, blockchain_instance=self)
             active_accounts_authority.append([addaccount["id"], 1])
 
         # voting account
         voting_account = Account(
-            proxy_account or "proxy-to-self", peerplays_instance=self)
+            proxy_account or "proxy-to-self", blockchain_instance=self)
 
         op = {
             "fee": {"amount": 0, "asset_id": "1.3.0"},
@@ -629,7 +656,7 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         op = operations.Account_upgrade(**{
             "fee": {"amount": 0, "asset_id": "1.3.0"},
             "account_to_upgrade": account["id"],
@@ -685,7 +712,7 @@ class PeerPlays(object):
             raise ValueError(
                 "Permission needs to be either 'owner', or 'active"
             )
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
 
         if not weight:
             weight = account[permission]["weight_threshold"]
@@ -699,7 +726,7 @@ class PeerPlays(object):
             ])
         except:
             try:
-                foreign_account = Account(foreign, peerplays_instance=self)
+                foreign_account = Account(foreign, blockchain_instance=self)
                 authority["account_auths"].append([
                     foreign_account["id"],
                     weight
@@ -749,7 +776,7 @@ class PeerPlays(object):
             raise ValueError(
                 "Permission needs to be either 'owner', or 'active"
             )
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         authority = account[permission]
 
         try:
@@ -763,7 +790,7 @@ class PeerPlays(object):
             ))
         except:
             try:
-                foreign_account = Account(foreign, peerplays_instance=self)
+                foreign_account = Account(foreign, blockchain_instance=self)
                 affected_items = list(
                     filter(lambda x: x[0] == foreign_account["id"],
                            authority["account_auths"]))
@@ -825,7 +852,7 @@ class PeerPlays(object):
 
         PublicKey(key, prefix=self.prefix)
 
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         account["options"]["memo_key"] = key
         op = operations.Account_update(**{
             "fee": {"amount": 0, "asset_id": "1.3.0"},
@@ -850,14 +877,14 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         options = account["options"]
 
         if not isinstance(witnesses, (list, set, tuple)):
             witnesses = {witnesses}
 
         for witness in witnesses:
-            witness = Witness(witness, peerplays_instance=self)
+            witness = Witness(witness, blockchain_instance=self)
             options["votes"].append(witness["vote_id"])
 
         options["votes"] = list(set(options["votes"]))
@@ -887,14 +914,14 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         options = account["options"]
 
         if not isinstance(witnesses, (list, set, tuple)):
             witnesses = {witnesses}
 
         for witness in witnesses:
-            witness = Witness(witness, peerplays_instance=self)
+            witness = Witness(witness, blockchain_instance=self)
             if witness["vote_id"] in options["votes"]:
                 options["votes"].remove(witness["vote_id"])
 
@@ -925,14 +952,14 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         options = account["options"]
 
         if not isinstance(committees, (list, set, tuple)):
             committees = {committees}
 
         for committee in committees:
-            committee = Committee(committee, peerplays_instance=self)
+            committee = Committee(committee, blockchain_instance=self)
             options["votes"].append(committee["vote_id"])
 
         options["votes"] = list(set(options["votes"]))
@@ -962,14 +989,14 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         options = account["options"]
 
         if not isinstance(committees, (list, set, tuple)):
             committees = {committees}
 
         for committee in committees:
-            committee = Committee(committee, peerplays_instance=self)
+            committee = Committee(committee, blockchain_instance=self)
             if committee["vote_id"] in options["votes"]:
                 options["votes"].remove(committee["vote_id"])
 
@@ -1008,7 +1035,7 @@ class PeerPlays(object):
         if not approver and not is_key:
             approver = account
         elif approver and not is_key:
-            approver = Account(approver, peerplays_instance=self)
+            approver = Account(approver, blockchain_instance=self)
         else:
             approver = PublicKey(approver)
 
@@ -1017,7 +1044,7 @@ class PeerPlays(object):
 
         op = []
         for proposal_id in proposal_ids:
-            proposal = Proposal(proposal_id, peerplays_instance=self)
+            proposal = Proposal(proposal_id, blockchain_instance=self)
             update_dict = {
                 "fee": {"amount": 0, "asset_id": "1.3.0"},
                 'fee_paying_account': account["id"],
@@ -1053,18 +1080,18 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         if not approver:
             approver = account
         else:
-            approver = Account(approver, peerplays_instance=self)
+            approver = Account(approver, blockchain_instance=self)
 
         if not isinstance(proposal_ids, (list, set, tuple)):
             proposal_ids = {proposal_ids}
 
         op = []
         for proposal_id in proposal_ids:
-            proposal = Proposal(proposal_id, peerplays_instance=self)
+            proposal = Proposal(proposal_id, blockchain_instance=self)
             op.append(operations.Proposal_update(**{
                 "fee": {"amount": 0, "asset_id": "1.3.0"},
                 'fee_paying_account': account["id"],
@@ -1414,7 +1441,7 @@ class PeerPlays(object):
         event_id="0.0.0",
         rules_id="0.0.0",
         asset=None,
-        delay_before_settling=60 * 5,
+        delay_before_settling=0,
         never_in_play=False,
         account=None,
         **kwargs
@@ -1429,7 +1456,7 @@ class PeerPlays(object):
             :param peerplays.asset.Asset asset: Asset to be used for this
                 market
             :param int delay_before_settling: Delay in seconds before settling
-                (defaults to 5 minutes)
+                (defaults to 0 seconds - immediatelly)
             :param bool never_in_play: Set this market group as *never in play*
                 (defaults to *False*)
             :param str account: (optional) the account to allow access
@@ -1442,8 +1469,8 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
-        asset = Asset(asset, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
+        asset = Asset(asset, blockchain_instance=self)
         if event_id[0] == "1":
             # Test if object exists
             Event(event_id)
@@ -1500,7 +1527,7 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account, peerplays_instance=self)
+        account = Account(account, blockchain_instance=self)
         bmg = BettingMarketGroup(betting_market_group_id)
 
         op_data = {
